Enum Shape
pub enum Shape {
Square(u32),
Rectangular(u32, u32),
}Expand description
Struct for storing the information about the shape of the image. This struct is being used with the construction of image inside the speciesnet crates.
Variants
Implementations