Struct BoundingBox
pub struct BoundingBox { /* private fields */ }Expand description
Struct for storing the bounding box point of an image.
Implementations
impl BoundingBox
impl BoundingBox
pub fn new(x1: f64, y1: f64, x2: f64, y2: f64) -> BoundingBox
pub fn from_xywh_coordinates(
center_x: f64,
center_y: f64,
width: f64,
height: f64,
) -> BoundingBox
pub fn from_xywh_coordinates( center_x: f64, center_y: f64, width: f64, height: f64, ) -> BoundingBox
Construct the BoundingBox struct from center_x, center_y, width, and height values.
pub fn from_megadetector_coordinates(
min_x: f64,
min_y: f64,
width: f64,
height: f64,
) -> BoundingBox
pub fn from_megadetector_coordinates( min_x: f64, min_y: f64, width: f64, height: f64, ) -> BoundingBox
Constructs the BoundingBox struct from given min_x, min_y, width and height
values.
pub fn from_xyxy_tensor(
tensor: ArrayBase<ViewRepr<&f32>, Dim<[usize; 1]>>,
) -> Result<BoundingBox, Error>
pub fn from_xyxy_tensor( tensor: ArrayBase<ViewRepr<&f32>, Dim<[usize; 1]>>, ) -> Result<BoundingBox, Error>
Tries to convert an ArrayView1 in format of (x1, y1, x2, y2) to the bounding box struct.
pub fn from_xywh_tensor(
tensor: ArrayBase<ViewRepr<&f32>, Dim<[usize; 1]>>,
) -> Result<BoundingBox, Error>
pub fn from_xywh_tensor( tensor: ArrayBase<ViewRepr<&f32>, Dim<[usize; 1]>>, ) -> Result<BoundingBox, Error>
Tries to convert a ArrayView1 in format of (center_y, center_y, width, height) to the bounding box struct.
pub fn area(&self) -> f64
pub fn as_xyxy_bounding_box(&self) -> (f64, f64, f64, f64)
pub fn as_xyxy_bounding_box(&self) -> (f64, f64, f64, f64)
Returns the values of the coordinates in a form of (x1, y1, x2, y2) tuple format.
pub fn as_xywh_bounding_box(&self) -> (f64, f64, f64, f64)
pub fn as_xywh_bounding_box(&self) -> (f64, f64, f64, f64)
Returns the values of the coordinates in a form of (center_x, center_y, width, height)
tuple format.
pub fn as_megadetector_bounding_box(&self) -> (f64, f64, f64, f64)
pub fn as_megadetector_bounding_box(&self) -> (f64, f64, f64, f64)
Returns the values of the coordinates in a form on (x1, y1, width, height) tuple
format.
pub fn normalize(self, width: u32, height: u32) -> BoundingBox
pub fn normalize(self, width: u32, height: u32) -> BoundingBox
Normalize the BoundingBox to be under 0..1 by the given width and height.
pub fn scale(
self,
resized_width: u32,
resized_height: u32,
width: u32,
height: u32,
) -> BoundingBox
pub fn scale( self, resized_width: u32, resized_height: u32, width: u32, height: u32, ) -> BoundingBox
Rescales BoundingBox to the given width and height.
Function is copied from yolov5 scale_boxes function.
pub fn x1(&self) -> f64
pub fn y1(&self) -> f64
pub fn x2(&self) -> f64
pub fn y2(&self) -> f64